@@ -6,7 +6,7 @@ class TokenGenerator:
 		self.code = code
 
 
-	def gen(self, type: str, ID: str, key: str) -> stc:
+	def gen(self, type: str, ID: str, key: str) -> str:
 		return f'{self.code}.t.{type}.{ID}:{generator_utils.sha256(ID+generator_utils.sha256(key))}_{generator_utils.sha256(generator_utils.sha256(key)+ID+generator_utils.random_sha256())}'
 
 	@staticmethod
